=======
History
=======

0.1.2 (2019-10-27)
------------------

* Move RPC & Consume initialization to common module
* Provide consume & is_rpc decorators
* `WcraasWorker` is now an Abstract Class.


0.1.1 (2019-10-02)
------------------

* Mark docs as stable.


0.1.0 (2019-09-21)
------------------

* First release on PyPI.
